package App::watcher;
use strict;
use warnings;
use 5.008008;
our $VERSION='0.13';
1;
__END__

=encoding utf8

=head1 NAME

watcher - watch the file updates

=head1 DESCRIPTION

See L<watcher>

=head1 AUTHOR

Tokuhiro Matsuno E<lt>tokuhirom AAJKLFJEF@ GMAIL COME<gt>

=head1 LICENSE

Copyright (C) Tokuhiro Matsuno

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

